@@ -254,7 +254,9 @@ travel_time_matrix <- function(r5r_core,
   # time window
   checkmate::assert_numeric(time_window, lower=1)
   time_window <- as.integer(time_window)
-  draws <- time_window *5
+
+  draws_per_minute <- getOption("r5r.montecarlo_draws", default = 5L)
+  draws <- time_window * draws_per_minute
   draws <- as.integer(draws)
 
   # percentiles
